fn build_connector(spec: ConnectorSpec) -> Result<Connector, ConnectionError>Expand description
Convert a ConnectorSpec into a runtime Connector by wiring up the
OpenSSL context. All filesystem I/O for CAs happens here.
fn build_connector(spec: ConnectorSpec) -> Result<Connector, ConnectionError>Convert a ConnectorSpec into a runtime Connector by wiring up the
OpenSSL context. All filesystem I/O for CAs happens here.