escape_options_value

Function escape_options_value 

fn escape_options_value(value: &str) -> String
Escape a value for embedding inside the libpq options connection parameter.

Within the options string, spaces separate -c key=value tokens unless escaped, and backslash is the escape character. Only spaces and backslashes are special; all other characters are literal.