pub struct IntrospectionClient<'a> {
pub(crate) client: &'a Client,
}Expand description
Domain sub-client for metadata and object introspection operations.
Fields
client: &'a ClientImplementations
Sourceimpl IntrospectionClient<'_>
impl IntrospectionClient<'_>
Sourcepub async fn get_current_user(&self) -> Result<String, ConnectionError>
pub async fn get_current_user(&self) -> Result<String, ConnectionError>
Get the current Materialize user/role.
Sourcepub async fn check_objects_exist(
&self,
objects: &BTreeSet<ObjectId>,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
pub async fn check_objects_exist( &self, objects: &BTreeSet<ObjectId>, ) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which objects from a set exist in the production database.
Sourcepub async fn check_catalog_objects_exist(
&self,
objects: &BTreeSet<ObjectId>,
catalog_table: &str,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
pub async fn check_catalog_objects_exist( &self, objects: &BTreeSet<ObjectId>, catalog_table: &str, ) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which objects from a set exist in a specific catalog table.
Sourcepub async fn check_tables_exist(
&self,
tables: &BTreeSet<ObjectId>,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
pub async fn check_tables_exist( &self, tables: &BTreeSet<ObjectId>, ) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which tables from the given set exist in the database.
Sourcepub async fn check_sources_exist(
&self,
sources: &BTreeSet<ObjectId>,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
pub async fn check_sources_exist( &self, sources: &BTreeSet<ObjectId>, ) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which sources from the given set exist in the database.
Sourcepub async fn check_secrets_exist(
&self,
secrets: &BTreeSet<ObjectId>,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
pub async fn check_secrets_exist( &self, secrets: &BTreeSet<ObjectId>, ) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which secrets from the given set exist in the database.
Sourcepub async fn check_connections_exist(
&self,
connections: &BTreeSet<ObjectId>,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
pub async fn check_connections_exist( &self, connections: &BTreeSet<ObjectId>, ) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which connections from the given set exist in the database.
Sourcepub async fn check_sinks_exist(
&self,
sinks: &BTreeSet<ObjectId>,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
pub async fn check_sinks_exist( &self, sinks: &BTreeSet<ObjectId>, ) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which sinks from the given set exist in the database.
Sourcepub async fn check_schemas_exist(
&self,
schemas: &[(String, String)],
) -> Result<BTreeSet<(String, String)>, ConnectionError>
pub async fn check_schemas_exist( &self, schemas: &[(String, String)], ) -> Result<BTreeSet<(String, String)>, ConnectionError>
Check which schemas from a set of (database, schema) pairs exist.
Sourcepub async fn check_clusters_exist(
&self,
clusters: &[String],
) -> Result<BTreeSet<String>, ConnectionError>
pub async fn check_clusters_exist( &self, clusters: &[String], ) -> Result<BTreeSet<String>, ConnectionError>
Check which clusters from a set of names exist.
Sourcepub async fn find_sinks_depending_on_schemas(
&self,
schemas: &[SchemaQualifier],
) -> Result<Vec<DependentSink>, ConnectionError>
pub async fn find_sinks_depending_on_schemas( &self, schemas: &[SchemaQualifier], ) -> Result<Vec<DependentSink>, ConnectionError>
Find sinks that depend on objects in the specified schemas.
Sourcepub async fn check_connection_exists(
&self,
database: &str,
schema: &str,
name: &str,
) -> Result<bool, ConnectionError>
pub async fn check_connection_exists( &self, database: &str, schema: &str, name: &str, ) -> Result<bool, ConnectionError>
Check if a connection exists in the specified database and schema.
Sourcepub async fn object_exists(
&self,
database: &str,
schema: &str,
object: &str,
) -> Result<bool, ConnectionError>
pub async fn object_exists( &self, database: &str, schema: &str, object: &str, ) -> Result<bool, ConnectionError>
Check if an object (MV, table, source) exists in the specified schema.
Sourcepub async fn get_staging_schemas(
&self,
deploy_id: &str,
) -> Result<Vec<SchemaQualifier>, ConnectionError>
pub async fn get_staging_schemas( &self, deploy_id: &str, ) -> Result<Vec<SchemaQualifier>, ConnectionError>
Get staging schema names for a specific deployment.
Sourcepub async fn get_staging_clusters(
&self,
deploy_id: &str,
) -> Result<Vec<String>, ConnectionError>
pub async fn get_staging_clusters( &self, deploy_id: &str, ) -> Result<Vec<String>, ConnectionError>
Get staging cluster names for a specific deployment.
Sourcepub async fn drop_schema_objects(
&self,
database: &str,
schema: &str,
) -> Result<Vec<String>, ConnectionError>
pub async fn drop_schema_objects( &self, database: &str, schema: &str, ) -> Result<Vec<String>, ConnectionError>
Drop all objects in a schema.
Sourcepub async fn drop_objects(
&self,
objects: &BTreeSet<ObjectId>,
) -> Result<Vec<String>, ConnectionError>
pub async fn drop_objects( &self, objects: &BTreeSet<ObjectId>, ) -> Result<Vec<String>, ConnectionError>
Drop specific objects by their ObjectIds.
Sourcepub async fn drop_staging_schemas(
&self,
schemas: &[SchemaQualifier],
) -> Result<(), ConnectionError>
pub async fn drop_staging_schemas( &self, schemas: &[SchemaQualifier], ) -> Result<(), ConnectionError>
Drop staging schemas by name.
Sourcepub async fn drop_staging_clusters(
&self,
clusters: &[String],
) -> Result<(), ConnectionError>
pub async fn drop_staging_clusters( &self, clusters: &[String], ) -> Result<(), ConnectionError>
Drop staging clusters by name.
Sourcepub async fn schema_exists(
&self,
database: &str,
schema: &str,
) -> Result<bool, ConnectionError>
pub async fn schema_exists( &self, database: &str, schema: &str, ) -> Result<bool, ConnectionError>
Check if a schema exists in the specified database.
Sourcepub async fn network_policy_exists(
&self,
name: &str,
) -> Result<bool, ConnectionError>
pub async fn network_policy_exists( &self, name: &str, ) -> Result<bool, ConnectionError>
Check if a network policy exists.
Sourcepub async fn role_exists(&self, name: &str) -> Result<bool, ConnectionError>
pub async fn role_exists(&self, name: &str) -> Result<bool, ConnectionError>
Check if a role exists.
Sourcepub async fn get_role_members(
&self,
name: &str,
) -> Result<Vec<String>, ConnectionError>
pub async fn get_role_members( &self, name: &str, ) -> Result<Vec<String>, ConnectionError>
Get the members granted to a role.
Sourcepub async fn get_role_parameters(
&self,
name: &str,
) -> Result<Vec<String>, ConnectionError>
pub async fn get_role_parameters( &self, name: &str, ) -> Result<Vec<String>, ConnectionError>
Get session default parameter names for a role.
Sourcepub async fn cluster_exists(&self, name: &str) -> Result<bool, ConnectionError>
pub async fn cluster_exists(&self, name: &str) -> Result<bool, ConnectionError>
Check if a cluster exists.
Sourcepub async fn get_cluster(
&self,
name: &str,
) -> Result<Option<Cluster>, ConnectionError>
pub async fn get_cluster( &self, name: &str, ) -> Result<Option<Cluster>, ConnectionError>
Get a cluster by name.
Sourcepub async fn list_clusters(&self) -> Result<Vec<Cluster>, ConnectionError>
pub async fn list_clusters(&self) -> Result<Vec<Cluster>, ConnectionError>
List all clusters.
Sourcepub async fn get_cluster_config(
&self,
name: &str,
) -> Result<Option<ClusterConfig>, ConnectionError>
pub async fn get_cluster_config( &self, name: &str, ) -> Result<Option<ClusterConfig>, ConnectionError>
Get cluster configuration including replicas and grants.
Sourcepub async fn get_cluster_grants(
&self,
name: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>
pub async fn get_cluster_grants( &self, name: &str, ) -> Result<Vec<ObjectGrant>, ConnectionError>
Get privilege grants on a cluster by name.
Sourcepub async fn get_network_policy_grants(
&self,
name: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>
pub async fn get_network_policy_grants( &self, name: &str, ) -> Result<Vec<ObjectGrant>, ConnectionError>
Get privilege grants on a network policy by name.
Sourcepub async fn get_database_object_grants(
&self,
catalog_table: &str,
database: &str,
schema: &str,
name: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>
pub async fn get_database_object_grants( &self, catalog_table: &str, database: &str, schema: &str, name: &str, ) -> Result<Vec<ObjectGrant>, ConnectionError>
Get privilege grants on a database object.
Sourcepub async fn get_connection_create_sql(
&self,
database: &str,
schema: &str,
name: &str,
) -> Result<Option<String>, ConnectionError>
pub async fn get_connection_create_sql( &self, database: &str, schema: &str, name: &str, ) -> Result<Option<String>, ConnectionError>
Get the CREATE CONNECTION SQL for an existing connection.
Sourcepub async fn get_default_privilege_grants_for_cluster(
&self,
name: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>
pub async fn get_default_privilege_grants_for_cluster( &self, name: &str, ) -> Result<Vec<ObjectGrant>, ConnectionError>
Get default privilege grants for a cluster by name.
Sourcepub async fn get_default_privilege_grants_for_network_policy(
&self,
name: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>
pub async fn get_default_privilege_grants_for_network_policy( &self, name: &str, ) -> Result<Vec<ObjectGrant>, ConnectionError>
Get default privilege grants for a network policy by name.
Sourcepub async fn get_default_privilege_grants_for_database_object(
&self,
catalog_table: &str,
database: &str,
schema: &str,
name: &str,
object_type: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>
pub async fn get_default_privilege_grants_for_database_object( &self, catalog_table: &str, database: &str, schema: &str, name: &str, object_type: &str, ) -> Result<Vec<ObjectGrant>, ConnectionError>
Get default privilege grants for a database object.